#
# spec file for package freerdp
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libfreerdp-1_0

Name:           freerdp
Version:        1.0.1
Release:        6.1
Summary:        Remote Desktop Viewer Client
License:        Apache-2.0
Group:          Productivity/Networking/Other
Url:            http://www.freerdp.com/
Source0:        %{name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM freerdp-fix-bitmap-cache.patch zawertun@gmail.com -- Fix a problem with the bitmap cache resulting in garbled images (backported from upstream git)
Patch0:         freerdp-fix-bitmap-cache.patch
# PATCH-FIX-UPSTREAM freerdp-fix-FindPCSC-macro.patch https://github.com/FreeRDP/FreeRDP/issues/562 gberh@opensuse.org -- Fix the build by setting PCSC_LIBRARIES and PCSC_INCLUDE_DIRS variables explicitly which are otherwise empty
Patch1:         freerdp-fix-FindPCSC-macro.patch
# PATCH-FIX-UPSTREAM freerdp-fix-numlock-behavior.patch https://github.com/FreeRDP/FreeRDP/pull/564 zawertun@gmail.com -- Fix incorrect num lock state when connecting
Patch2:         freerdp-fix-incorrect-numlock-state.patch
BuildRequires:  cmake
BuildRequires:  cups-devel
BuildRequires:  ed
BuildRequires:  xmlto
BuildRequires:  xorg-x11-devel
BuildRequires:  zlib-devel
%if 0%{?suse_version} < 1210
BuildRequires:	alsa-devel
BuildRequires:	pcsc-lite-devel
BuildRequires:	libpulse-devel
BuildRequires:	openssl-devel
%else
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(libpcsclite)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(openssl)
%endif
Recommends:     libfreerdp-plugins
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FreeRDP is a client-side implementation of the Remote Desktop Protocol (RDP)
following the Microsoft Open Specifications. This package provides the client
application.

%package -n %{libname}
Summary:        Remote Desktop Viewer Library
Group:          System/Libraries

%description -n %{libname}
FreeRDP is a client-side implementation of the Remote Desktop Protocol (RDP)
following the Microsoft Open Specifications. This package provides the shared
library.

%package -n %{libname}-plugins
Summary:        Plugins for %{libname}
Group:          System/Libraries
Provides:       libfreerdp-plugins = %{version}
Requires:       %{libname} = %{version}

%description -n %{libname}-plugins
This package provides plugins for %{libname}.

%package devel
Summary:        Development Files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
This package contains development files necessary for developing applications
based on libfreerdp.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
# use a versioned subdirectory for plugins in order to comply with the shared
# library policy
ed -s CMakeLists.txt 2>/dev/null <<'EOF'
,s/FREERDP_PLUGIN_PATH "\${CMAKE_INSTALL_PREFIX}\/\${CMAKE_INSTALL_LIBDIR}\/freerdp"/FREERDP_PLUGIN_PATH "\${CMAKE_INSTALL_PREFIX}\/\${CMAKE_INSTALL_LIBDIR}\/%{libname}"/
w
EOF
# fix for building with alsa
echo "pkg_check_modules(ALSA alsa)" > cmake/FindALSA.cmake

%build
mkdir build
cd build
export CFLAGS="%{optflags}"
cmake \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DCMAKE_INSTALL_LIBDIR=%{_lib} \
    -DCMAKE_BUILD_TYPE=Release \
    -DWITH_ALSA=ON \
    -DWITH_PULSEAUDIO=ON \
    -DWITH_PCSC=ON \
    -DWITH_CUPS=ON \
    -DWITH_FFMPEG=OFF \
    -DWITH_SSE2=OFF \
    ..
make %{?_smp_mflags} VERBOSE=1

%install
cd build
%__make DESTDIR=%{buildroot} install

# remove keymaps as we make use of libxkbfile
rm -rf $RPM_BUILD_ROOT/usr/share/freerdp/keymaps/

%post   -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc LICENSE README ChangeLog
%{_bindir}/xfreerdp
%{_datadir}/%{name}
%{_mandir}/man1/xfreerdp.1%{ext_man}

%files -n %{libname}
%defattr(-,root,root)
%doc LICENSE
%{_libdir}/libfreerdp-cache.so.*
%{_libdir}/libfreerdp-channels.so.*
%{_libdir}/libfreerdp-codec.so.*
%{_libdir}/libfreerdp-core.so.*
%{_libdir}/libfreerdp-gdi.so.*
%{_libdir}/libfreerdp-kbd.so.*
%{_libdir}/libfreerdp-rail.so.*
%{_libdir}/libfreerdp-utils.so.*

%files -n %{libname}-plugins
%defattr(-,root,root)
%doc LICENSE
%dir %{_libdir}/%{libname}
%{_libdir}/%{libname}/audin.so
%{_libdir}/%{libname}/audin_alsa.so
%{_libdir}/%{libname}/audin_pulse.so
%{_libdir}/%{libname}/cliprdr.so
%{_libdir}/%{libname}/disk.so
%{_libdir}/%{libname}/drdynvc.so
%{_libdir}/%{libname}/parallel.so
%{_libdir}/%{libname}/printer.so
%{_libdir}/%{libname}/rdpdr.so
%{_libdir}/%{libname}/rdpsnd.so
%{_libdir}/%{libname}/rdpsnd_alsa.so
%{_libdir}/%{libname}/rdpsnd_pulse.so
%{_libdir}/%{libname}/scard.so
%{_libdir}/%{libname}/serial.so
%{_libdir}/%{libname}/rail.so
%{_libdir}/%{libname}/rdpdbg.so
%{_libdir}/%{libname}/tsmf.so
%{_libdir}/%{libname}/tsmf_alsa.so
%{_libdir}/%{libname}/tsmf_pulse.so

%files devel
%defattr(-,root,root)
%dir %{_includedir}/freerdp
%dir %{_includedir}/freerdp/*
%{_includedir}/freerdp/*.h
%{_includedir}/freerdp/*/*.h
%{_libdir}/libfreerdp-*.so
%{_libdir}/pkgconfig/freerdp.pc

%changelog
* Sun Apr 29 2012 zawertun@gmail.com
- added freerdp-fix-incorrect-numlock-state.patch which fixes
  incorrect num lock state when connecting
  (https://github.com/FreeRDP/FreeRDP/pull/564)
* Sun Apr 22 2012 gber@opensuse.org
- added freerdp-fix-FindPCSC-macro.patch which fixes the build by
  setting PCSC_LIBRARIES and PCSC_INCLUDE_DIRS variables explicitly
  which are otherwise empty
  (https://github.com/FreeRDP/FreeRDP/issues/562)
* Thu Apr 19 2012 gber@opensuse.org
- applied fix for a bug in freerdp-fix-bitmap-cache.patch from
  upstream git
* Fri Mar 30 2012 zawertun@gmail.com
- added freerdp-fix-bitmap-cache.patch fixing a problem with the
  bitmap cache resulting in garbled images
  (https://github.com/FreeRDP/FreeRDP/issues/348)
* Wed Mar 28 2012 gber@opensuse.org
- split off -plugins subpackage
- specfile cleanup
* Tue Mar  6 2012 gankov@opensuse.org
- rewrote spec for using cmake.
- update to version 1.0.1
  - FreeRDP 1.x series is a complete rewrite now licensed under
    the Apache License 2.0
  - RemoteFX
  - Both encoder and decoder
  - SSE2 and NEON optimization
  - NSCodec
  - RemoteApp
  - Working, minor glitches
  - Multimedia Redirection
  - ffmpeg support
  - Network Level Authentication (NLA)
  - NTLMv2
  - Certificate validation
  - FIPS-compliant RDP security
  - new build system (cmake)
  - added official logo and icon
* Fri Dec  2 2011 gber@opensuse.org
- add explicit dependency on libtool
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Sep 22 2011 gber@opensuse.org
- cleanup to comply with the packaging policy
  - add header
  - use the correct license format
  - remove %%clean section
  - simplify the manipulation of PLUGIN_PATH
  - remove %%debug_package
  - add meaningful description
  - do not recompres the source tarball any more
  - corrected URLs
* Tue Jun  7 2011 pascal.bleser@opensuse.org
- fix bnc#688484 by passing --with-sound=alsa and alsa-devel in BuildRequires
* Wed Nov 17 2010 pascal.bleser@opensuse.org
- rewrote most of the spec file (wrong group, wrong subpackages, ldconfig
  called on devel package, shlibs inj devel package, ...)
- update to 0.8.2:
  * libfreerdp:
    + fix buffer overflow when local timezone doesn't fit in 32 bytes
    + fix data corruption after TLS license package
    + free TLS resources to avoid memory leaks
  * mcs:
    + fix connecting to VirtualBox with extra channels
  * rdpsnd plugin:
    + ensure the ALSA device is closed when freeing resources
  * rdpdr plugin:
    + fix various memory leaks
    + fix a segfault in multi-session environment
* Wed Oct 27 2010 hrustov@gmail.com
- initial build
